@@ -135,6 +135,8 @@ See also: [`interval`](@ref), [`±`](@ref), [`..`](@ref) and [`@I_str`](@ref).
 # Examples
 
 ```jldoctest
+julia> using IntervalArithmetic
+
 julia> setdisplay(:full);
 
 julia> bareinterval(1//1, π)
@@ -318,6 +320,8 @@ In the case of a complex interval `x`, this is semantically equivalent to
 # Examples
 
 ```jldoctest
+julia> using IntervalArithmetic
+
 julia> isguaranteed(bareinterval(1))
 true
 
@@ -340,7 +344,7 @@ isguaranteed(::Number) = false
 #
 
 """
-    interval(T, a, b, d = com)
+    interval([T,] a, b, d = com; format = :infsup)
 
 Create the interval ``[a, b]`` according to the IEEE Standard 1788-2015. The
 validity of the interval is checked by [`is_valid_interval`](@ref): if `true`
@@ -357,19 +361,21 @@ See also: [`±`](@ref), [`..`](@ref) and [`@I_str`](@ref).
 # Examples
 
 ```jldoctest
+julia> using IntervalArithmetic
+
 julia> setdisplay(:full);
 
 julia> interval(1//1, π)
-Interval{Rational{Int64}}(1//1, 85563208//27235615, com)
+Interval{Rational{Int64}}(1//1, 85563208//27235615, com, true)
 
 julia> interval(Rational{Int32}, 1//1, π)
-Interval{Rational{Int32}}(1//1, 85563208//27235615, com)
+Interval{Rational{Int32}}(1//1, 85563208//27235615, com, true)
 
 julia> interval(1, π)
-Interval{Float64}(1.0, 3.1415926535897936, com)
+Interval{Float64}(1.0, 3.1415926535897936, com, true)
 
 julia> interval(BigFloat, 1, π)
-Interval{BigFloat}(1.0, 3.141592653589793238462643383279502884197169399375105820974944592307816406286233, com)
+Interval{BigFloat}(1.0, 3.141592653589793238462643383279502884197169399375105820974944592307816406286233, com, true)
 ```
 """
 function interval(::Type{T}, a, b, d::Decoration = com; format::Symbol = :infsup) where {T}
@@ -386,8 +392,6 @@ end
 interval(a, d::Decoration = com; format::Symbol = :infsup) = interval(promote_numtype(numtype(a), numtype(a)), a, d; format = format)
 
 # some useful extra constructor
-interval(::Type{T}, a::Tuple, d::Decoration = com; format::Symbol = :infsup) where {T} = interval(T, a..., d; format = format)
-interval(a::Tuple, d::Decoration = com; format::Symbol = :infsup) = interval(a..., d; format = format)
 interval(::Type{T}, A::AbstractArray, d::Decoration = com; format::Symbol = :infsup) where {T} = interval.(T, A, d; format = format)
 interval(A::AbstractArray, d::Decoration = com; format::Symbol = :infsup) = interval.(A, d; format = format)
 interval(::Type{T}, A::AbstractArray, B::AbstractArray, d::Decoration = com; format::Symbol = :infsup) where {T} = interval.(T, A, B, d; format = format)
@@ -401,7 +405,7 @@ interval(T::Type, d::Decoration; format::Symbol = :infsup) = throw(MethodError(i
 # standard format
 
 """
-    _interval_infsup(T<:NumTypes, a, b, [d::Decoration])
+    _interval_infsup(T<:NumTypes, a, b, d::Decoration)
 
 Internal constructor for intervals described by their lower and upper bounds,
 i.e. of the form ``[a, b]``.
@@ -459,52 +463,52 @@ function _interval_infsup(::Type{T}, x, y::Union{BareInterval,Interval}, d::Deco
     end
 end
 
-_interval_infsup(::Type{T}, a::Complex, b::Union{BareInterval,Interval}, d::Decoration = com) where {T<:NumTypes} =
+_interval_infsup(::Type{T}, a::Complex, b::Union{BareInterval,Interval}, d::Decoration) where {T<:NumTypes} =
     complex(_interval_infsup(T, real(a), real(b), d), _interval_infsup(T, imag(a), imag(b), d))
-_interval_infsup(::Type{T}, a::Union{BareInterval,Interval}, b::Complex, d::Decoration = com) where {T<:NumTypes} =
+_interval_infsup(::Type{T}, a::Union{BareInterval,Interval}, b::Complex, d::Decoration) where {T<:NumTypes} =
     complex(_interval_infsup(T, real(a), real(b), d), _interval_infsup(T, imag(a), imag(b), d))
 
-_interval_infsup(::Type{T}, a::Complex, b::Complex, d::Decoration = com) where {T<:NumTypes} =
+_interval_infsup(::Type{T}, a::Complex, b::Complex, d::Decoration) where {T<:NumTypes} =
     complex(_interval_infsup(T, real(a), real(b), d), _interval_infsup(T, imag(a), imag(b), d))
-_interval_infsup(::Type{T}, a::Complex, b, d::Decoration = com) where {T<:NumTypes} =
+_interval_infsup(::Type{T}, a::Complex, b, d::Decoration) where {T<:NumTypes} =
     complex(_interval_infsup(T, real(a), real(b), d), _interval_infsup(T, imag(a), imag(b), d))
-_interval_infsup(::Type{T}, a, b::Complex, d::Decoration = com) where {T<:NumTypes} =
+_interval_infsup(::Type{T}, a, b::Complex, d::Decoration) where {T<:NumTypes} =
     complex(_interval_infsup(T, real(a), real(b), d), _interval_infsup(T, imag(a), imag(b), d))
 
 # midpoint constructors
 
 """
-    _interval_midpoint(T<:NumTypes, m, r, d = com)
+    _interval_midpoint(T<:NumTypes, m, r, d::Decoration)
 
 Internal constructor for intervals described by their midpoint and radius, i.e.
 of the form ``m \\pm r``.
 """
-function _interval_midpoint(::Type{T}, m, r, d::Decoration = com) where {T<:NumTypes}
+function _interval_midpoint(::Type{T}, m, r, d::Decoration) where {T<:NumTypes}
     x = _interval_infsup(T, m, m, d)
     r = _interval_infsup(T, r, r, d)
     precedes(zero(r), r) && return _interval_infsup(T, x - r, x + r, d)
     return throw(DomainError(r, "must be positive"))
 end
 
-_interval_midpoint(::Type{T}, m::Complex, r, d::Decoration = com) where {T<:NumTypes} =
+_interval_midpoint(::Type{T}, m::Complex, r, d::Decoration) where {T<:NumTypes} =
     complex(_interval_midpoint(T, real(m), r, d), _interval_midpoint(T, imag(m), r, d))
 
-function _interval_midpoint(::Type{T}, m, r::Complex{<:Interval}, d::Decoration = com) where {T<:NumTypes}
+function _interval_midpoint(::Type{T}, m, r::Complex{<:Interval}, d::Decoration) where {T<:NumTypes}
     isthinzero(imag(r)) || return throw(DomainError(r, "imaginary part must be zero"))
     return _interval_midpoint(T, m, real(r), d)
 end
 
-function _interval_midpoint(::Type{T}, m, r::Complex, d::Decoration = com) where {T<:NumTypes}
+function _interval_midpoint(::Type{T}, m, r::Complex, d::Decoration) where {T<:NumTypes}
     iszero(imag(r)) || return throw(DomainError(r, "imaginary part must be zero"))
     return _interval_midpoint(T, m, real(r), d)
 end
 
-function _interval_midpoint(::Type{T}, m::Complex, r::Complex{<:Interval}, d::Decoration = com) where {T<:NumTypes}
+function _interval_midpoint(::Type{T}, m::Complex, r::Complex{<:Interval}, d::Decoration) where {T<:NumTypes}
     isthinzero(imag(r)) || return throw(DomainError(r, "imaginary part must be zero"))
     return _interval_midpoint(T, m, real(r), d)
 end
 
-function _interval_midpoint(::Type{T}, m::Complex, r::Complex, d::Decoration = com) where {T<:NumTypes}
+function _interval_midpoint(::Type{T}, m::Complex, r::Complex, d::Decoration) where {T<:NumTypes}
     iszero(imag(r)) || return throw(DomainError(r, "imaginary part must be zero"))
     return _interval_midpoint(T, m, real(r), d)
 end
@@ -576,16 +580,18 @@ to `parse(Interval{T}, string(x))` if `x` is a `Number`.
 # Examples
 
 ```jldoctest
+julia> using IntervalArithmetic
+
 julia> setdisplay(:full);
 
 julia> x = IntervalArithmetic.atomic(Float64, 0.1)
-Interval{Float64}(0.09999999999999999, 0.1, com)
+Interval{Float64}(0.09999999999999999, 0.1, com, true)
 
 julia> in_interval(1//10, IntervalArithmetic.atomic(Float64, 0.1))
 true
 
 julia> IntervalArithmetic.atomic(Float64, 0.3)
-Interval{Float64}(0.3, 0.30000000000000004, com)
+Interval{Float64}(0.3, 0.30000000000000004, com, true)
 
 julia> in_interval(3//10, IntervalArithmetic.atomic(Float64, 0.3))
 true
@@ -617,6 +623,8 @@ constructor [`atomic`](@ref).
 # Examples
 
 ```jldoctest
+julia> using IntervalArithmetic
+
 julia> setdisplay(:full);
 
 julia> @macroexpand @interval sin(1) # Float64 is the default bound type
@@ -626,7 +634,7 @@ julia> @macroexpand @interval Float32 sin(1)
 :(sin(IntervalArithmetic.atomic(Float32, 1)))
 
 julia> @interval Float64 sin(1) exp(1)
-Interval{Float64}(0.8414709848078965, 2.7182818284590455, com)
+Interval{Float64}(0.8414709848078965, 2.7182818284590455, com, true)
 ```
 """
 macro interval(T, expr)
